==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/imagepreviewplugin/.rcc/qrc_imagepreviewplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/imagepreviewplugin/imagepreviewplugin.png
  0x0,0x0,0x2,0x49,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xd,0xd7,0x0,0x0,0xd,0xd7,0x1,
  0x42,0x28,0x9b,0x78,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd8,0xc,0x1c,
  0x13,0x2a,0x22,0x49,0xed,0xa1,0x21,0x0,0x0,0x1,0xc9,0x49,0x44,0x41,0x54,0x78,
  0xda,0xa5,0x93,0x4d,0x6b,0x13,0x51,0x14,0x86,0x9f,0x3b,0x99,0xce,0xbd,0xc9,0x4c,
  0xc8,0x24,0xda,0xd0,0x69,0xd5,0x4e,0x3f,0x54,0x4,0x11,0x52,0xa1,0x45,0x10,0x5,
  0x85,0x82,0x5,0x51,0xa8,0x20,0x88,0xe0,0x42,0xff,0x84,0x8b,0xe2,0xba,0xe0,0xda,
  0xdf,0x20,0xae,0xdc,0x14,0xfc,0x58,0x74,0x21,0x45,0xd0,0x56,0x5d,0x84,0xa2,0xc1,
  0x68,0x15,0xab,0xd8,0x64,0x9a,0x40,0x63,0x48,0x4d,0x26,0xd7,0xf,0x32,0x50,0xd4,
  0x40,0x6b,0x1f,0x38,0x9b,0xb3,0x78,0xce,0x79,0xe1,0x1c,0x1,0x18,0x40,0xc,0x10,
  0xec,0xc,0xd,0x84,0x26,0x90,0x2,0x7c,0xc0,0xdd,0x81,0x44,0x3,0x55,0x60,0xc5,
  0x4,0x7c,0xad,0xf5,0xb,0xfe,0x3,0x21,0xc4,0x98,0xd9,0x99,0x4c,0xee,0xd0,0xc,
  0xe7,0x6a,0x77,0xd9,0x54,0x6b,0x7c,0xa9,0x1f,0x45,0x96,0x7a,0xe9,0x1b,0xec,0xe7,
  0xfb,0xd0,0x33,0xe,0xc8,0xf,0xf4,0x57,0x3c,0xee,0x59,0xd7,0xb9,0xff,0x6d,0x1f,
  0x0,0xcd,0xc5,0x69,0x0,0xd7,0x8c,0xd6,0x3e,0x19,0x9b,0x87,0xcc,0x57,0x44,0x6,
  0x9c,0x37,0x2,0x8d,0x41,0x96,0x14,0xef,0xbc,0x6,0x87,0x27,0x1c,0x8e,0xc8,0x61,
  0xca,0x73,0x45,0x1e,0x88,0x91,0xad,0x49,0x85,0x41,0x7,0x99,0xfd,0xc8,0x27,0xcf,
  0x21,0x48,0x2a,0xca,0x31,0x83,0x1e,0xb3,0x7,0x6d,0xc2,0xf3,0x20,0xc3,0xba,0x7f,
  0x8c,0x6a,0x9f,0xc5,0xd4,0x58,0x40,0xc2,0x51,0xa8,0x9f,0x15,0x11,0x9,0x58,0xda,
  0x33,0x49,0xb5,0x38,0xca,0x42,0x65,0x2f,0x46,0x2d,0x8e,0x94,0x16,0x6e,0x2b,0xc1,
  0xcd,0x95,0x4b,0x94,0xa,0xa7,0x99,0xaf,0x37,0x79,0x35,0x30,0x8e,0x65,0xc7,0x51,
  0xf6,0x3f,0x4,0xab,0xee,0x35,0x64,0xcd,0x67,0x62,0x69,0x4,0xb3,0x91,0xa0,0x94,
  0xd5,0x18,0x18,0xf4,0xc6,0x5c,0xce,0xcf,0xfa,0xb8,0x83,0x17,0x99,0xcd,0x8f,0xa3,
  0xba,0x6d,0x20,0x93,0x69,0x36,0xce,0x1c,0x27,0xce,0x26,0xd2,0x7c,0x4f,0xa1,0x25,
  0x78,0x68,0x2f,0x62,0x4,0x2d,0x9c,0x2b,0x6d,0xa,0x4f,0x47,0xd9,0xd0,0x49,0x94,
  0x23,0x7f,0x57,0x84,0x49,0x87,0x5f,0xcd,0xc0,0x9e,0xc2,0x9a,0xd4,0x78,0x9f,0xef,
  0x70,0x35,0x7c,0xc9,0x93,0xd4,0x7e,0xd6,0x6e,0xc0,0xa3,0xa6,0xe2,0x71,0x90,0x45,
  0x39,0x44,0xfc,0x2d,0x88,0x72,0x55,0x4e,0x4c,0xb3,0xbc,0x50,0x66,0x6e,0xfd,0x35,
  0x7,0xcf,0xde,0xe2,0x76,0x3d,0x8d,0xd6,0x1a,0x65,0x13,0xd1,0x45,0x10,0xe5,0x6a,
  0x35,0xb8,0x30,0x90,0xa7,0x71,0xea,0x32,0x6f,0x6d,0x8f,0x76,0x5b,0x13,0xd1,0x4d,
  0xa0,0xb7,0xa,0x74,0x65,0x95,0xfc,0x72,0x91,0xcc,0x50,0x12,0x2b,0x21,0xb7,0x73,
  0xd2,0xe4,0xf4,0x1f,0x84,0x61,0xa8,0xb7,0x3,0x90,0x13,0x40,0x7a,0x37,0xcf,0xb4,
  0xeb,0x77,0xfe,0x1,0x7c,0x5b,0xbc,0x7b,0x43,0x74,0xcb,0xfa,0x0,0x0,0x0,0x0,
  0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // imagepreviewplugin
  0x0,0x12,
  0xd,0x67,0xd5,0x5e,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,
  0x0,0x6e,
    // imagepreviewplugin.png
  0x0,0x16,
  0x5,0x7b,0x98,0xe7,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,
  0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/imagepreviewplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/imagepreviewplugin/imagepreviewplugin.png
  0x0,0x0,0x0,0x2a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/imagepreviewplugin/.rcc/qrc_imagepreviewplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/imagepreviewplugin/imagepreviewplugin.png
  0x0,0x0,0x2,0x49,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xd,0xd7,0x0,0x0,0xd,0xd7,0x1,
  0x42,0x28,0x9b,0x78,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd8,0xc,0x1c,
  0x13,0x2a,0x22,0x49,0xed,0xa1,0x21,0x0,0x0,0x1,0xc9,0x49,0x44,0x41,0x54,0x78,
  0xda,0xa5,0x93,0x4d,0x6b,0x13,0x51,0x14,0x86,0x9f,0x3b,0x99,0xce,0xbd,0xc9,0x4c,
  0xc8,0x24,0xda,0xd0,0x69,0xd5,0x4e,0x3f,0x54,0x4,0x11,0x52,0xa1,0x45,0x10,0x5,
  0x85,0x82,0x5,0x51,0xa8,0x20,0x88,0xe0,0x42,0xff,0x84,0x8b,0xe2,0xba,0xe0,0xda,
  0xdf,0x20,0xae,0xdc,0x14,0xfc,0x58,0x74,0x21,0x45,0xd0,0x56,0x5d,0x84,0xa2,0xc1,
  0x68,0x15,0xab,0xd8,0x64,0x9a,0x40,0x63,0x48,0x4d,0x26,0xd7,0xf,0x32,0x50,0xd4,
  0x40,0x6b,0x1f,0x38,0x9b,0xb3,0x78,0xce,0x79,0xe1,0x1c,0x1,0x18,0x40,0xc,0x10,
  0xec,0xc,0xd,0x84,0x26,0x90,0x2,0x7c,0xc0,0xdd,0x81,0x44,0x3,0x55,0x60,0xc5,
  0x4,0x7c,0xad,0xf5,0xb,0xfe,0x3,0x21,0xc4,0x98,0xd9,0x99,0x4c,0xee,0xd0,0xc,
  0xe7,0x6a,0x77,0xd9,0x54,0x6b,0x7c,0xa9,0x1f,0x45,0x96,0x7a,0xe9,0x1b,0xec,0xe7,
  0xfb,0xd0,0x33,0xe,0xc8,0xf,0xf4,0x57,0x3c,0xee,0x59,0xd7,0xb9,0xff,0x6d,0x1f,
  0x0,0xcd,0xc5,0x69,0x0,0xd7,0x8c,0xd6,0x3e,0x19,0x9b,0x87,0xcc,0x57,0x44,0x6,
  0x9c,0x37,0x2,0x8d,0x41,0x96,0x14,0xef,0xbc,0x6,0x87,0x27,0x1c,0x8e,0xc8,0x61,
  0xca,0x73,0x45,0x1e,0x88,0x91,0xad,0x49,0x85,0x41,0x7,0x99,0xfd,0xc8,0x27,0xcf,
  0x21,0x48,0x2a,0xca,0x31,0x83,0x1e,0xb3,0x7,0x6d,0xc2,0xf3,0x20,0xc3,0xba,0x7f,
  0x8c,0x6a,0x9f,0xc5,0xd4,0x58,0x40,0xc2,0x51,0xa8,0x9f,0x15,0x11,0x9,0x58,0xda,
  0x33,0x49,0xb5,0x38,0xca,0x42,0x65,0x2f,0x46,0x2d,0x8e,0x94,0x16,0x6e,0x2b,0xc1,
  0xcd,0x95,0x4b,0x94,0xa,0xa7,0x99,0xaf,0x37,0x79,0x35,0x30,0x8e,0x65,0xc7,0x51,
  0xf6,0x3f,0x4,0xab,0xee,0x35,0x64,0xcd,0x67,0x62,0x69,0x4,0xb3,0x91,0xa0,0x94,
  0xd5,0x18,0x18,0xf4,0xc6,0x5c,0xce,0xcf,0xfa,0xb8,0x83,0x17,0x99,0xcd,0x8f,0xa3,
  0xba,0x6d,0x20,0x93,0x69,0x36,0xce,0x1c,0x27,0xce,0x26,0xd2,0x7c,0x4f,0xa1,0x25,
  0x78,0x68,0x2f,0x62,0x4,0x2d,0x9c,0x2b,0x6d,0xa,0x4f,0x47,0xd9,0xd0,0x49,0x94,
  0x23,0x7f,0x57,0x84,0x49,0x87,0x5f,0xcd,0xc0,0x9e,0xc2,0x9a,0xd4,0x78,0x9f,0xef,
  0x70,0x35,0x7c,0xc9,0x93,0xd4,0x7e,0xd6,0x6e,0xc0,0xa3,0xa6,0xe2,0x71,0x90,0x45,
  0x39,0x44,0xfc,0x2d,0x88,0x72,0x55,0x4e,0x4c,0xb3,0xbc,0x50,0x66,0x6e,0xfd,0x35,
  0x7,0xcf,0xde,0xe2,0x76,0x3d,0x8d,0xd6,0x1a,0x65,0x13,0xd1,0x45,0x10,0xe5,0x6a,
  0x35,0xb8,0x30,0x90,0xa7,0x71,0xea,0x32,0x6f,0x6d,0x8f,0x76,0x5b,0x13,0xd1,0x4d,
  0xa0,0xb7,0xa,0x74,0x65,0x95,0xfc,0x72,0x91,0xcc,0x50,0x12,0x2b,0x21,0xb7,0x73,
  0xd2,0xe4,0xf4,0x1f,0x84,0x61,0xa8,0xb7,0x3,0x90,0x13,0x40,0x7a,0x37,0xcf,0xb4,
  0xeb,0x77,0xfe,0x1,0x7c,0x5b,0xbc,0x7b,0x43,0x74,0xcb,0xfa,0x0,0x0,0x0,0x0,
  0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // imagepreviewplugin
  0x0,0x12,
  0xd,0x67,0xd5,0x5e,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,
  0x0,0x6e,
    // imagepreviewplugin.png
  0x0,0x16,
  0x5,0x7b,0x98,0xe7,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,
  0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/imagepreviewplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/imagepreviewplugin/imagepreviewplugin.png
  0x0,0x0,0x0,0x2a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_imagepreviewplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imagepreviewplugin)(); }
   } dummy;
}
